<?php

class Shopware_Plugins_Frontend_rvdwBackground_Bootstrap extends Shopware_Components_Plugin_Bootstrap{


    public function getCapabilities(){
        return array(
            "install" => true,
            "update" => true,
            "enable" => true

        );
    }
    public function getLabel(){
            return "Background Frontend";
        }

    public function getVersion(){
            return "3.0.0";
        }
    public function getInfo(){
            return array(
                "version" => $this->getVersion(),
                "label" => $this->getLabel(),
                "supplier" => "7synth",
                "description" => "This Plugin will refine your frontend background.",
                "support" => "info@7synth.com",
                "link" => "http://7synth.com",
                "author" => "R.v.d.Waydbrink",
                "copyright" => "2016 R.v.d.Waydbrink",
                "license" => "by request"
            );
        }
    public function install(){
        $this->registerEvents();
        $this->createConfiguration();
        return array(
                "success" => true,
                "invalidateCache" => array("frontend")
            );
        }
    public function uninstall(){
            return array(
                "success" => true,
                "invalidateCache" => array("frontend")
            );
        }
    private function registerEvents(){
            $this->subscribeEvent(
                'Theme_Compiler_Collect_Plugin_Less',
                'addLessFiles'
            );

        }

    /**
     *
     * @param Enlight_Event_EventArgs $args
     * @return \Doctrine\Common\Collections\ArrayCollection
    */
    public function addLessFiles(Enlight_Event_EventArgs $args)
    {
        $shop = $args->getShop();
        $config = $this->collection->getConfig($this->name,$shop);

        $less = new \Shopware\Components\Theme\LessDefinition(
        /* Configuration */
            array(
                'backgroundColor' => $config->get('backgroundColor'),
                'backgroundImageDesktop' => 'url("' . $config->get('backgroundImageDesktop') . '")',
                'backgroundImageTablet' => 'url("' . $config->get('backgroundImageTablet') . '")',
                'backgroundImageMobile' => 'url("' . $config->get('backgroundImageMobile') . '")',
                'backgroundAttachment' => $config->get('backgroundAttachment'),
                'backgroundSize' => $config->get('backgroundSize'),
                'backgroundPosition' => $config->get('backgroundPosition'),
                'backgroundRepeat' => $config->get('backgroundRepeat'),
                'backgroundHeader' => $config->get('backgroundHeader'),
                'backgroundFooter' => $config->get('backgroundFooter')
            ),
            /* Less files to compile */
            array(__DIR__ . '/Views/responsive/frontend/_public/src/less/all.less'),
            /* Import directory */
            __DIR__
        );

        return new Doctrine\Common\Collections\ArrayCollection(array($less));
    }
    public function createConfiguration(){
        $form = $this->Form();

        $form->setElement('color', 'backgroundColor',
            array(
                'label' => 'Background Color',
                'value' => '#eeeeee',
                "description" => "Choose a background color.",
                'scope' => Shopware\Models\Config\Element::SCOPE_SHOP
            )
        );
        $form->setElement('mediaselection','backgroundImageDesktop',
            array(
                'label' => 'Background Image Desktop',
                'value' => NULL,
                "description" => "Choose a background image from media manager.",
                'scope' => Shopware\Models\Config\Element::SCOPE_SHOP,
                'readOnly' => false,
            )
        );
        $form->setElement('mediaselection','backgroundImageTablet',
            array(
                'label' => 'Background Image Tablet',
                'value' => NULL,
                "description" => "Choose a background image from media manager.",
                'scope' => Shopware\Models\Config\Element::SCOPE_SHOP,
                'readOnly' => false,
            )
        );
        $form->setElement('mediaselection','backgroundImageMobile',
            array(
                'label' => 'Background Image Mobile',
                'value' => NULL,
                "description" => "Choose a background image from media manager.",
                'scope' => Shopware\Models\Config\Element::SCOPE_SHOP,
                'readOnly' => false,
            )
        );
        $form->setElement('select', 'backgroundAttachment',
            array('label' => 'Background Attachment',
                "value" => array("scroll", 'scroll'),
                'store' => array(
                    array("scroll", 'scroll'),
                    array("fixed", 'fixed'),
                    array("local", 'local'),
                    array("initial", 'initial'),
                    array("inherit", 'inherit')
                ),
                "description" => "Choose a background attachment ",
                'scope' => Shopware\Models\Config\Element::SCOPE_SHOP
            )
        );
        $form->setElement('select', 'backgroundSize',
            array('label' => 'Background Size',
                "value" => array("auto", 'auto'),
                'store' => array(
                    array("auto", 'auto'),
                    array("cover", 'cover'),
                    array("contain", 'contain'),
                    array("initial", 'initial'),
                    array("inherit", 'inherit')
                ),
                "description" => "Choose a background size",
                'scope' => Shopware\Models\Config\Element::SCOPE_SHOP
            )
        );
        $form->setElement('select', 'backgroundPosition',
            array('label' => 'Background Position',
                "value" => array("left top", 'left top'),
                'store' => array(
                    array("left top", 'left top'),
                    array("left center", 'left center'),
                    array("left bottom", 'left bottom'),
                    array("right top", 'right top'),
                    array("right center", 'right center'),
                    array("right bottom", 'right bottom'),
                    array("center top", 'center top'),
                    array("center center", 'center center'),
                    array("center bottom", 'center bottom'),
                    array("initial", 'initial'),
                    array("inherit", 'inherit')
                ),
                "description" => "Choose a background size",
                'scope' => Shopware\Models\Config\Element::SCOPE_SHOP
            )
        );
        $form->setElement('select', 'backgroundRepeat',
            array('label' => 'Background Repeat',
                "value" => array("no-repeat", 'no-repeat'),
                'store' => array(
                    array("no-repeat", 'no-repeat'),
                    array("repeat", 'repeat'),
                    array("repeat-x", 'repeat-x'),
                    array("repeat-y", 'repeat-y'),
                    array("initial", 'initial'),
                    array("inherit", 'inherit')
                ),
                "description" => "Choose a background Repeat",
                'scope' => Shopware\Models\Config\Element::SCOPE_SHOP
            )
        );
        $form->setElement("checkbox","backgroundHeader",
            array("label"=>"Transparent Header",
                "value"=>true,
                "description" => "Transparency of the header.",
                "scope" => Shopware\Models\Config\Element::SCOPE_SHOP
            )
        );
        $form->setElement("checkbox","backgroundFooter",
            array("label"=>"Transparent Footer",
                "value"=>true,
                "description" => "Transparency of the footer.",
                "scope" => Shopware\Models\Config\Element::SCOPE_SHOP
            )
        );
        $form->save();
    }
}